"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import yandex.cloud.mdb.greenplum.v1.config_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Host(google.protobuf.message.Message):
    """A Greenplum® cluster host resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Type:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Host._Type.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TYPE_UNSPECIFIED: Host._Type.ValueType  # 0
        """Host type is not specified. Default value."""
        MASTER: Host._Type.ValueType  # 1
        """A Greenplum® master host."""
        REPLICA: Host._Type.ValueType  # 2
        """A Greenplum® master replica host."""
        SEGMENT: Host._Type.ValueType  # 3
        """A Greenplum® segment host."""

    class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
    TYPE_UNSPECIFIED: Host.Type.ValueType  # 0
    """Host type is not specified. Default value."""
    MASTER: Host.Type.ValueType  # 1
    """A Greenplum® master host."""
    REPLICA: Host.Type.ValueType  # 2
    """A Greenplum® master replica host."""
    SEGMENT: Host.Type.ValueType  # 3
    """A Greenplum® segment host."""

    class _Health:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _HealthEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Host._Health.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN: Host._Health.ValueType  # 0
        """Health of the host is unknown. Default value."""
        ALIVE: Host._Health.ValueType  # 1
        """The host is performing all its functions normally."""
        DEAD: Host._Health.ValueType  # 2
        """The host is inoperable and cannot perform any of its essential functions."""
        DEGRADED: Host._Health.ValueType  # 3
        """The host is working below capacity or not fully functional."""
        UNBALANCED: Host._Health.ValueType  # 4
        """One or more segments are not in the preferred role."""

    class Health(_Health, metaclass=_HealthEnumTypeWrapper): ...
    UNKNOWN: Host.Health.ValueType  # 0
    """Health of the host is unknown. Default value."""
    ALIVE: Host.Health.ValueType  # 1
    """The host is performing all its functions normally."""
    DEAD: Host.Health.ValueType  # 2
    """The host is inoperable and cannot perform any of its essential functions."""
    DEGRADED: Host.Health.ValueType  # 3
    """The host is working below capacity or not fully functional."""
    UNBALANCED: Host.Health.ValueType  # 4
    """One or more segments are not in the preferred role."""

    NAME_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    ZONE_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    HEALTH_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    ASSIGN_PUBLIC_IP_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the Greenplum® host.

    The host name is assigned by the platform at creation time and cannot be changed.

    The name is unique across all MDB hosts that exist on the platform, as it defines the FQDN of the host.
    """
    cluster_id: builtins.str
    """ID of the Greenplum® cluster. The ID is assigned by the platform at creation time."""
    zone_id: builtins.str
    """ID of the availability zone the Greenplum® host belongs to."""
    type: global___Host.Type.ValueType
    """Type of the host. If the field has default value, it is not returned in the response."""
    health: global___Host.Health.ValueType
    """Aggregated health of the host. If the field has default value, it is not returned in the response."""
    subnet_id: builtins.str
    """ID of the subnet that the host belongs to."""
    assign_public_ip: builtins.bool
    """Determines whether a public IP is assigned to the host."""
    @property
    def resources(self) -> yandex.cloud.mdb.greenplum.v1.config_pb2.Resources:
        """Resources allocated to the Greenplum® host."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        cluster_id: builtins.str = ...,
        zone_id: builtins.str = ...,
        type: global___Host.Type.ValueType = ...,
        resources: yandex.cloud.mdb.greenplum.v1.config_pb2.Resources | None = ...,
        health: global___Host.Health.ValueType = ...,
        subnet_id: builtins.str = ...,
        assign_public_ip: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resources", b"resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["assign_public_ip", b"assign_public_ip", "cluster_id", b"cluster_id", "health", b"health", "name", b"name", "resources", b"resources", "subnet_id", b"subnet_id", "type", b"type", "zone_id", b"zone_id"]) -> None: ...

global___Host = Host



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.struct_pb2
import sys
import typing
import yandex.cloud.storage.v1.bucket_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetBucketRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _View:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ViewEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[GetBucketRequest._View.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        VIEW_UNSPECIFIED: GetBucketRequest._View.ValueType  # 0
        VIEW_BASIC: GetBucketRequest._View.ValueType  # 1
        """Returns basic information about a bucket.

        The following fields will _not_ be returned: [Bucket.acl], [Bucket.cors], [Bucket.website_settings],
        [Bucket.lifecycle_rules], [Bucket.tags].
        """
        VIEW_ACL: GetBucketRequest._View.ValueType  # 2
        """Returns basic information and access control list (ACL) for the bucket.

        The following fields will _not_ be returned: [Bucket.cors], [Bucket.website_settings], [Bucket.lifecycle_rules],
        [Bucket.tags].
        """
        VIEW_FULL: GetBucketRequest._View.ValueType  # 3
        """Returns full information about a bucket."""

    class View(_View, metaclass=_ViewEnumTypeWrapper): ...
    VIEW_UNSPECIFIED: GetBucketRequest.View.ValueType  # 0
    VIEW_BASIC: GetBucketRequest.View.ValueType  # 1
    """Returns basic information about a bucket.

    The following fields will _not_ be returned: [Bucket.acl], [Bucket.cors], [Bucket.website_settings],
    [Bucket.lifecycle_rules], [Bucket.tags].
    """
    VIEW_ACL: GetBucketRequest.View.ValueType  # 2
    """Returns basic information and access control list (ACL) for the bucket.

    The following fields will _not_ be returned: [Bucket.cors], [Bucket.website_settings], [Bucket.lifecycle_rules],
    [Bucket.tags].
    """
    VIEW_FULL: GetBucketRequest.View.ValueType  # 3
    """Returns full information about a bucket."""

    NAME_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the bucket to return.

    To get the bucket name, make a [BucketService.List] request.
    """
    view: global___GetBucketRequest.View.ValueType
    """Scope of information about the bucket to return.

    Access to scopes is managed via [Identity and Access Management roles](/docs/storage/security),
    bucket [ACL](/docs/storage/concepts/acl) and [policies](/docs/storage/concepts/policy).
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        view: global___GetBucketRequest.View.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "view", b"view"]) -> None: ...

global___GetBucketRequest = GetBucketRequest

@typing.final
class ListBucketsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list buckets in.

    To get the folder ID, make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id"]) -> None: ...

global___ListBucketsRequest = ListBucketsRequest

@typing.final
class ListBucketsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKETS_FIELD_NUMBER: builtins.int
    @property
    def buckets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.storage.v1.bucket_pb2.Bucket]:
        """List of buckets in the specified folder."""

    def __init__(
        self,
        *,
        buckets: collections.abc.Iterable[yandex.cloud.storage.v1.bucket_pb2.Bucket] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["buckets", b"buckets"]) -> None: ...

global___ListBucketsResponse = ListBucketsResponse

@typing.final
class CreateBucketRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    DEFAULT_STORAGE_CLASS_FIELD_NUMBER: builtins.int
    MAX_SIZE_FIELD_NUMBER: builtins.int
    ANONYMOUS_ACCESS_FLAGS_FIELD_NUMBER: builtins.int
    ACL_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the bucket.

    The name must be unique within the platform. For naming limitations and rules, see
    [documentation](/docs/storage/concepts/bucket#naming).
    """
    folder_id: builtins.str
    """ID of the folder to create a bucket in.

    To get the folder ID, make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    default_storage_class: builtins.str
    """Default storage class for objects in the bucket. Supported classes are standard storage (`STANDARD`), cold storage
    (`COLD`, `STANDARD_IA`, `NEARLINE` all synonyms), and ice storage (`ICE` and `GLACIER` are synonyms).
    For details, see [documentation](/docs/storage/concepts/storage-class).
    """
    max_size: builtins.int
    """Maximum size of the bucket.
    For details, see [documentation](/docs/storage/operations/buckets/limit-max-volume).
    """
    @property
    def anonymous_access_flags(self) -> yandex.cloud.storage.v1.bucket_pb2.AnonymousAccessFlags:
        """Flags for configuring public (anonymous) access to the bucket's content and settings.
        For details, see [documentation](/docs/storage/concepts/bucket#bucket-access).
        """

    @property
    def acl(self) -> yandex.cloud.storage.v1.bucket_pb2.ACL:
        """Access control list (ACL) of the bucket.
        For details, see [documentation](/docs/storage/concepts/acl).
        """

    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.storage.v1.bucket_pb2.Tag]:
        """List of tags for the bucket.
        For details, see [documentation](/docs/resource-manager/concepts/labels).
        """

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        folder_id: builtins.str = ...,
        default_storage_class: builtins.str = ...,
        max_size: builtins.int = ...,
        anonymous_access_flags: yandex.cloud.storage.v1.bucket_pb2.AnonymousAccessFlags | None = ...,
        acl: yandex.cloud.storage.v1.bucket_pb2.ACL | None = ...,
        tags: collections.abc.Iterable[yandex.cloud.storage.v1.bucket_pb2.Tag] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["acl", b"acl", "anonymous_access_flags", b"anonymous_access_flags"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["acl", b"acl", "anonymous_access_flags", b"anonymous_access_flags", "default_storage_class", b"default_storage_class", "folder_id", b"folder_id", "max_size", b"max_size", "name", b"name", "tags", b"tags"]) -> None: ...

global___CreateBucketRequest = CreateBucketRequest

@typing.final
class CreateBucketMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the bucket that is being created."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name"]) -> None: ...

global___CreateBucketMetadata = CreateBucketMetadata

@typing.final
class UpdateBucketRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    ANONYMOUS_ACCESS_FLAGS_FIELD_NUMBER: builtins.int
    DEFAULT_STORAGE_CLASS_FIELD_NUMBER: builtins.int
    MAX_SIZE_FIELD_NUMBER: builtins.int
    CORS_FIELD_NUMBER: builtins.int
    WEBSITE_SETTINGS_FIELD_NUMBER: builtins.int
    VERSIONING_FIELD_NUMBER: builtins.int
    LIFECYCLE_RULES_FIELD_NUMBER: builtins.int
    POLICY_FIELD_NUMBER: builtins.int
    ACL_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    OBJECT_LOCK_FIELD_NUMBER: builtins.int
    ENCRYPTION_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the bucket to update.

    The name cannot be updated.

    To get the bucket name, make a [BucketService.List] request.
    """
    default_storage_class: builtins.str
    """Default storage class for objects in the bucket. Supported classes are standard storage (`STANDARD`), cold storage
    (`COLD`, `STANDARD_IA`, `NEARLINE` all synonyms), and ice storage (`ICE` and `GLACIER` are synonyms).
    For details, see [documentation](/docs/storage/concepts/storage-class).
    """
    max_size: builtins.int
    """Maximum size of the bucket, in bytes.
    For details, see [documentation](/docs/storage/operations/buckets/limit-max-volume).
    """
    versioning: yandex.cloud.storage.v1.bucket_pb2.Versioning.ValueType
    """Bucket versioning status.
    For details, see [documentation](/docs/storage/concepts/versioning).
    """
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Update mask that specifies which attributes of the bucket should be updated.
        Use * for full update.
        """

    @property
    def anonymous_access_flags(self) -> yandex.cloud.storage.v1.bucket_pb2.AnonymousAccessFlags:
        """Flags for configuring public (anonymous) access to the bucket's content and settings.
        For details, see [documentation](/docs/storage/concepts/bucket#bucket-access).
        """

    @property
    def cors(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.storage.v1.bucket_pb2.CorsRule]:
        """List of rules for cross-domain requests to objects in the bucket (cross-origin resource sharing, CORS).
        For details, see [documentation](/docs/storage/concepts/cors).
        """

    @property
    def website_settings(self) -> yandex.cloud.storage.v1.bucket_pb2.WebsiteSettings:
        """Configuration for hosting a static website in the bucket.
        For details, see [documentation](/docs/storage/concepts/hosting).
        """

    @property
    def lifecycle_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.storage.v1.bucket_pb2.LifecycleRule]:
        """List of object lifecycle rules for the bucket.
        For details, see [documentation](/docs/storage/concepts/lifecycles).
        """

    @property
    def policy(self) -> google.protobuf.struct_pb2.Struct:
        """Bucket policies that set permissions for actions with the bucket, its objects, and groups of objects.
        For details, see [documentation](/docs/storage/concepts/policy).
        """

    @property
    def acl(self) -> yandex.cloud.storage.v1.bucket_pb2.ACL:
        """Access control list (ACL) of the bucket.
        For details, see [documentation](/docs/storage/concepts/acl).
        """

    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.storage.v1.bucket_pb2.Tag]:
        """List of tags for the bucket.
        For details, see [documentation](/docs/resource-manager/concepts/labels).
        """

    @property
    def object_lock(self) -> yandex.cloud.storage.v1.bucket_pb2.ObjectLock:
        """Configuration for object lock on the bucket.
        For details about the concept, see [documentation](/docs/storage/concepts/object-lock).
        """

    @property
    def encryption(self) -> yandex.cloud.storage.v1.bucket_pb2.Encryption:
        """Configuration for bucket's encryption
        For detauls, see [documentation](/docs/storage/concepts/encryption)
        """

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        anonymous_access_flags: yandex.cloud.storage.v1.bucket_pb2.AnonymousAccessFlags | None = ...,
        default_storage_class: builtins.str = ...,
        max_size: builtins.int = ...,
        cors: collections.abc.Iterable[yandex.cloud.storage.v1.bucket_pb2.CorsRule] | None = ...,
        website_settings: yandex.cloud.storage.v1.bucket_pb2.WebsiteSettings | None = ...,
        versioning: yandex.cloud.storage.v1.bucket_pb2.Versioning.ValueType = ...,
        lifecycle_rules: collections.abc.Iterable[yandex.cloud.storage.v1.bucket_pb2.LifecycleRule] | None = ...,
        policy: google.protobuf.struct_pb2.Struct | None = ...,
        acl: yandex.cloud.storage.v1.bucket_pb2.ACL | None = ...,
        tags: collections.abc.Iterable[yandex.cloud.storage.v1.bucket_pb2.Tag] | None = ...,
        object_lock: yandex.cloud.storage.v1.bucket_pb2.ObjectLock | None = ...,
        encryption: yandex.cloud.storage.v1.bucket_pb2.Encryption | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["acl", b"acl", "anonymous_access_flags", b"anonymous_access_flags", "encryption", b"encryption", "object_lock", b"object_lock", "policy", b"policy", "update_mask", b"update_mask", "website_settings", b"website_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["acl", b"acl", "anonymous_access_flags", b"anonymous_access_flags", "cors", b"cors", "default_storage_class", b"default_storage_class", "encryption", b"encryption", "lifecycle_rules", b"lifecycle_rules", "max_size", b"max_size", "name", b"name", "object_lock", b"object_lock", "policy", b"policy", "tags", b"tags", "update_mask", b"update_mask", "versioning", b"versioning", "website_settings", b"website_settings"]) -> None: ...

global___UpdateBucketRequest = UpdateBucketRequest

@typing.final
class UpdateBucketMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the bucket that is being updated."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name"]) -> None: ...

global___UpdateBucketMetadata = UpdateBucketMetadata

@typing.final
class DeleteBucketRequest(google.protobuf.message.Message):
    """DeleteBucketRequest deletes requested bucket from the Cloud."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the bucket to update.

    To get the bucket name, make a [BucketService.List] request.
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name"]) -> None: ...

global___DeleteBucketRequest = DeleteBucketRequest

@typing.final
class DeleteBucketMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the bucket that is being deleted."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name"]) -> None: ...

global___DeleteBucketMetadata = DeleteBucketMetadata

@typing.final
class GetBucketStatsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the bucket to return the statistics for."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name"]) -> None: ...

global___GetBucketStatsRequest = GetBucketStatsRequest

@typing.final
class GetBucketHTTPSConfigRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the bucket to return the HTTPS configuration for."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name"]) -> None: ...

global___GetBucketHTTPSConfigRequest = GetBucketHTTPSConfigRequest

@typing.final
class SelfManagedHTTPSConfigParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATE_PEM_FIELD_NUMBER: builtins.int
    PRIVATE_KEY_PEM_FIELD_NUMBER: builtins.int
    certificate_pem: builtins.str
    """[PEM](https://en.wikipedia.org/wiki/Privacy-Enhanced_Mail)-encoded certificate."""
    private_key_pem: builtins.str
    """[PEM](https://en.wikipedia.org/wiki/Privacy-Enhanced_Mail)-encoded private key for the certificate."""
    def __init__(
        self,
        *,
        certificate_pem: builtins.str = ...,
        private_key_pem: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["certificate_pem", b"certificate_pem", "private_key_pem", b"private_key_pem"]) -> None: ...

global___SelfManagedHTTPSConfigParams = SelfManagedHTTPSConfigParams

@typing.final
class CertificateManagerHTTPSConfigParams(google.protobuf.message.Message):
    """A resource for a TLS certificate from Certificate Manager."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATE_ID_FIELD_NUMBER: builtins.int
    certificate_id: builtins.str
    """ID of the certificate.

    To get the list of all available certificates, make a [yandex.cloud.certificatemanager.v1.CertificateService.List]
    request.
    """
    def __init__(
        self,
        *,
        certificate_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["certificate_id", b"certificate_id"]) -> None: ...

global___CertificateManagerHTTPSConfigParams = CertificateManagerHTTPSConfigParams

@typing.final
class SetBucketHTTPSConfigRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    SELF_MANAGED_FIELD_NUMBER: builtins.int
    CERTIFICATE_MANAGER_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the bucket to update the HTTPS configuration for."""
    @property
    def self_managed(self) -> global___SelfManagedHTTPSConfigParams:
        """Your TLS certificate, uploaded directly.

        Object Storage only supports [PEM](https://en.wikipedia.org/wiki/Privacy-Enhanced_Mail)-encoded certificates.
        """

    @property
    def certificate_manager(self) -> global___CertificateManagerHTTPSConfigParams:
        """TLS certificate from Certificate Manager.

        To create a certificate in Certificate Manager, make a
        [yandex.cloud.certificatemanager.v1.CertificateService.Create] request.
        """

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        self_managed: global___SelfManagedHTTPSConfigParams | None = ...,
        certificate_manager: global___CertificateManagerHTTPSConfigParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["certificate_manager", b"certificate_manager", "params", b"params", "self_managed", b"self_managed"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["certificate_manager", b"certificate_manager", "name", b"name", "params", b"params", "self_managed", b"self_managed"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["params", b"params"]) -> typing.Literal["self_managed", "certificate_manager"] | None: ...

global___SetBucketHTTPSConfigRequest = SetBucketHTTPSConfigRequest

@typing.final
class SetBucketHTTPSConfigMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the bucket the HTTPS configuration is being updated for."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name"]) -> None: ...

global___SetBucketHTTPSConfigMetadata = SetBucketHTTPSConfigMetadata

@typing.final
class DeleteBucketHTTPSConfigRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the bucket to delete the HTTPS configuration for."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name"]) -> None: ...

global___DeleteBucketHTTPSConfigRequest = DeleteBucketHTTPSConfigRequest

@typing.final
class DeleteBucketHTTPSConfigMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the bucket the HTTPS configuration is being deleted for."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name"]) -> None: ...

global___DeleteBucketHTTPSConfigMetadata = DeleteBucketHTTPSConfigMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ClaimAgentStatusRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ClaimAgentStatusRequest._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: ClaimAgentStatusRequest._Status.ValueType  # 0
        READY_FOR_TEST: ClaimAgentStatusRequest._Status.ValueType  # 1
        PREPARING_TEST: ClaimAgentStatusRequest._Status.ValueType  # 2
        TESTING: ClaimAgentStatusRequest._Status.ValueType  # 3
        TANK_FAILED: ClaimAgentStatusRequest._Status.ValueType  # 4
        STOPPED: ClaimAgentStatusRequest._Status.ValueType  # 5
        UPLOADING_ARTIFACTS: ClaimAgentStatusRequest._Status.ValueType  # 6
        ERROR: ClaimAgentStatusRequest._Status.ValueType  # 7

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: ClaimAgentStatusRequest.Status.ValueType  # 0
    READY_FOR_TEST: ClaimAgentStatusRequest.Status.ValueType  # 1
    PREPARING_TEST: ClaimAgentStatusRequest.Status.ValueType  # 2
    TESTING: ClaimAgentStatusRequest.Status.ValueType  # 3
    TANK_FAILED: ClaimAgentStatusRequest.Status.ValueType  # 4
    STOPPED: ClaimAgentStatusRequest.Status.ValueType  # 5
    UPLOADING_ARTIFACTS: ClaimAgentStatusRequest.Status.ValueType  # 6
    ERROR: ClaimAgentStatusRequest.Status.ValueType  # 7

    AGENT_INSTANCE_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    STATUS_MESSAGE_FIELD_NUMBER: builtins.int
    agent_instance_id: builtins.str
    status: global___ClaimAgentStatusRequest.Status.ValueType
    status_message: builtins.str
    def __init__(
        self,
        *,
        agent_instance_id: builtins.str = ...,
        status: global___ClaimAgentStatusRequest.Status.ValueType = ...,
        status_message: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["agent_instance_id", b"agent_instance_id", "status", b"status", "status_message", b"status_message"]) -> None: ...

global___ClaimAgentStatusRequest = ClaimAgentStatusRequest

@typing.final
class ClaimAgentStatusResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_FIELD_NUMBER: builtins.int
    code: builtins.int
    def __init__(
        self,
        *,
        code: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["code", b"code"]) -> None: ...

global___ClaimAgentStatusResponse = ClaimAgentStatusResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.ai.llm.v1alpha.llm_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class TextGenerationServiceStub:
    """Service for text generation and conversation."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Instruct: grpc.UnaryStreamMultiCallable[
        yandex.cloud.ai.llm.v1alpha.llm_service_pb2.InstructRequest,
        yandex.cloud.ai.llm.v1alpha.llm_service_pb2.InstructResponse,
    ]
    """RPC method for instructing the model to generate text."""

    Chat: grpc.UnaryStreamMultiCallable[
        yandex.cloud.ai.llm.v1alpha.llm_service_pb2.ChatRequest,
        yandex.cloud.ai.llm.v1alpha.llm_service_pb2.ChatResponse,
    ]
    """RPC method for engaging in a chat conversation with the model."""

class TextGenerationServiceAsyncStub:
    """Service for text generation and conversation."""

    Instruct: grpc.aio.UnaryStreamMultiCallable[
        yandex.cloud.ai.llm.v1alpha.llm_service_pb2.InstructRequest,
        yandex.cloud.ai.llm.v1alpha.llm_service_pb2.InstructResponse,
    ]
    """RPC method for instructing the model to generate text."""

    Chat: grpc.aio.UnaryStreamMultiCallable[
        yandex.cloud.ai.llm.v1alpha.llm_service_pb2.ChatRequest,
        yandex.cloud.ai.llm.v1alpha.llm_service_pb2.ChatResponse,
    ]
    """RPC method for engaging in a chat conversation with the model."""

class TextGenerationServiceServicer(metaclass=abc.ABCMeta):
    """Service for text generation and conversation."""

    @abc.abstractmethod
    def Instruct(
        self,
        request: yandex.cloud.ai.llm.v1alpha.llm_service_pb2.InstructRequest,
        context: _ServicerContext,
    ) -> typing.Union[collections.abc.Iterator[yandex.cloud.ai.llm.v1alpha.llm_service_pb2.InstructResponse], collections.abc.AsyncIterator[yandex.cloud.ai.llm.v1alpha.llm_service_pb2.InstructResponse]]:
        """RPC method for instructing the model to generate text."""

    @abc.abstractmethod
    def Chat(
        self,
        request: yandex.cloud.ai.llm.v1alpha.llm_service_pb2.ChatRequest,
        context: _ServicerContext,
    ) -> typing.Union[collections.abc.Iterator[yandex.cloud.ai.llm.v1alpha.llm_service_pb2.ChatResponse], collections.abc.AsyncIterator[yandex.cloud.ai.llm.v1alpha.llm_service_pb2.ChatResponse]]:
        """RPC method for engaging in a chat conversation with the model."""

def add_TextGenerationServiceServicer_to_server(servicer: TextGenerationServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...

class TokenizerServiceStub:
    """Service for tokenizing input text."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Tokenize: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.llm.v1alpha.llm_service_pb2.TokenizeRequest,
        yandex.cloud.ai.llm.v1alpha.llm_service_pb2.TokenizeResponse,
    ]
    """RPC method for tokenizing input text."""

class TokenizerServiceAsyncStub:
    """Service for tokenizing input text."""

    Tokenize: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.llm.v1alpha.llm_service_pb2.TokenizeRequest,
        yandex.cloud.ai.llm.v1alpha.llm_service_pb2.TokenizeResponse,
    ]
    """RPC method for tokenizing input text."""

class TokenizerServiceServicer(metaclass=abc.ABCMeta):
    """Service for tokenizing input text."""

    @abc.abstractmethod
    def Tokenize(
        self,
        request: yandex.cloud.ai.llm.v1alpha.llm_service_pb2.TokenizeRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.llm.v1alpha.llm_service_pb2.TokenizeResponse, collections.abc.Awaitable[yandex.cloud.ai.llm.v1alpha.llm_service_pb2.TokenizeResponse]]:
        """RPC method for tokenizing input text."""

def add_TokenizerServiceServicer_to_server(servicer: TokenizerServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...

class EmbeddingsServiceStub:
    """Service for obtaining embeddings for text data."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Embedding: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.llm.v1alpha.llm_service_pb2.EmbeddingRequest,
        yandex.cloud.ai.llm.v1alpha.llm_service_pb2.EmbeddingResponse,
    ]
    """RPC method to obtain embeddings for input text data."""

class EmbeddingsServiceAsyncStub:
    """Service for obtaining embeddings for text data."""

    Embedding: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.llm.v1alpha.llm_service_pb2.EmbeddingRequest,
        yandex.cloud.ai.llm.v1alpha.llm_service_pb2.EmbeddingResponse,
    ]
    """RPC method to obtain embeddings for input text data."""

class EmbeddingsServiceServicer(metaclass=abc.ABCMeta):
    """Service for obtaining embeddings for text data."""

    @abc.abstractmethod
    def Embedding(
        self,
        request: yandex.cloud.ai.llm.v1alpha.llm_service_pb2.EmbeddingRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.llm.v1alpha.llm_service_pb2.EmbeddingResponse, collections.abc.Awaitable[yandex.cloud.ai.llm.v1alpha.llm_service_pb2.EmbeddingResponse]]:
        """RPC method to obtain embeddings for input text data."""

def add_EmbeddingsServiceServicer_to_server(servicer: EmbeddingsServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...

class TextGenerationAsyncServiceStub:
    """Service for asynchronous text generation."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Instruct: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.llm.v1alpha.llm_service_pb2.InstructRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """RPC method for instructing the model to generate text."""

class TextGenerationAsyncServiceAsyncStub:
    """Service for asynchronous text generation."""

    Instruct: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.llm.v1alpha.llm_service_pb2.InstructRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """RPC method for instructing the model to generate text."""

class TextGenerationAsyncServiceServicer(metaclass=abc.ABCMeta):
    """Service for asynchronous text generation."""

    @abc.abstractmethod
    def Instruct(
        self,
        request: yandex.cloud.ai.llm.v1alpha.llm_service_pb2.InstructRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """RPC method for instructing the model to generate text."""

def add_TextGenerationAsyncServiceServicer_to_server(servicer: TextGenerationAsyncServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.iam.v1.service_control_pb2
import yandex.cloud.iam.v1.service_control_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class ServiceControlServiceStub:
    """A set of methods for managing Service resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.service_control_service_pb2.GetServiceRequest,
        yandex.cloud.iam.v1.service_control_pb2.Service,
    ]
    """Returns the Service information in the specified resource container.

    To get the list of available Services, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.service_control_service_pb2.ListServicesRequest,
        yandex.cloud.iam.v1.service_control_service_pb2.ListServicesResponse,
    ]
    """Retrieves the list of Service in the specified resource container."""

    Enable: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.service_control_service_pb2.EnableServiceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Enable a service in the specified resource container."""

    Resume: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.service_control_service_pb2.ResumeServiceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Resume a service in the specified resource container."""

    Pause: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.service_control_service_pb2.PauseServiceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Pause a service in the specified resource container."""

    Disable: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.service_control_service_pb2.DisableServiceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Disable a service in the specified resource container."""

class ServiceControlServiceAsyncStub:
    """A set of methods for managing Service resources."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.service_control_service_pb2.GetServiceRequest,
        yandex.cloud.iam.v1.service_control_pb2.Service,
    ]
    """Returns the Service information in the specified resource container.

    To get the list of available Services, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.service_control_service_pb2.ListServicesRequest,
        yandex.cloud.iam.v1.service_control_service_pb2.ListServicesResponse,
    ]
    """Retrieves the list of Service in the specified resource container."""

    Enable: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.service_control_service_pb2.EnableServiceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Enable a service in the specified resource container."""

    Resume: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.service_control_service_pb2.ResumeServiceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Resume a service in the specified resource container."""

    Pause: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.service_control_service_pb2.PauseServiceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Pause a service in the specified resource container."""

    Disable: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.service_control_service_pb2.DisableServiceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Disable a service in the specified resource container."""

class ServiceControlServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing Service resources."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.iam.v1.service_control_service_pb2.GetServiceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.iam.v1.service_control_pb2.Service, collections.abc.Awaitable[yandex.cloud.iam.v1.service_control_pb2.Service]]:
        """Returns the Service information in the specified resource container.

        To get the list of available Services, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.iam.v1.service_control_service_pb2.ListServicesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.iam.v1.service_control_service_pb2.ListServicesResponse, collections.abc.Awaitable[yandex.cloud.iam.v1.service_control_service_pb2.ListServicesResponse]]:
        """Retrieves the list of Service in the specified resource container."""

    @abc.abstractmethod
    def Enable(
        self,
        request: yandex.cloud.iam.v1.service_control_service_pb2.EnableServiceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Enable a service in the specified resource container."""

    @abc.abstractmethod
    def Resume(
        self,
        request: yandex.cloud.iam.v1.service_control_service_pb2.ResumeServiceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Resume a service in the specified resource container."""

    @abc.abstractmethod
    def Pause(
        self,
        request: yandex.cloud.iam.v1.service_control_service_pb2.PauseServiceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Pause a service in the specified resource container."""

    @abc.abstractmethod
    def Disable(
        self,
        request: yandex.cloud.iam.v1.service_control_service_pb2.DisableServiceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Disable a service in the specified resource container."""

def add_ServiceControlServiceServicer_to_server(servicer: ServiceControlServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import yandex.cloud.mdb.opensearch.v1.config.opensearch_pb2
import yandex.cloud.mdb.opensearch.v1.maintenance_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Cluster(google.protobuf.message.Message):
    """An OpenSearch cluster resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Environment:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _EnvironmentEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Cluster._Environment.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ENVIRONMENT_UNSPECIFIED: Cluster._Environment.ValueType  # 0
        PRODUCTION: Cluster._Environment.ValueType  # 1
        """Stable environment with a conservative update policy:
        only hotfixes are applied during regular maintenance.
        """
        PRESTABLE: Cluster._Environment.ValueType  # 2
        """Environment with more aggressive update policy: new versions
        are rolled out irrespective of backward compatibility.
        """

    class Environment(_Environment, metaclass=_EnvironmentEnumTypeWrapper): ...
    ENVIRONMENT_UNSPECIFIED: Cluster.Environment.ValueType  # 0
    PRODUCTION: Cluster.Environment.ValueType  # 1
    """Stable environment with a conservative update policy:
    only hotfixes are applied during regular maintenance.
    """
    PRESTABLE: Cluster.Environment.ValueType  # 2
    """Environment with more aggressive update policy: new versions
    are rolled out irrespective of backward compatibility.
    """

    class _Health:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _HealthEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Cluster._Health.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        HEALTH_UNKNOWN: Cluster._Health.ValueType  # 0
        """Health of the cluster is unknown ([Host.health] for every host in the cluster is UNKNOWN)."""
        ALIVE: Cluster._Health.ValueType  # 1
        """Cluster is working normally ([Host.health] for every host in the cluster is ALIVE)."""
        DEAD: Cluster._Health.ValueType  # 2
        """Cluster is inoperable ([Host.health] for every host in the cluster is DEAD)."""
        DEGRADED: Cluster._Health.ValueType  # 3
        """Cluster is working below capacity ([Host.health] for at least one host in the cluster is not ALIVE)."""

    class Health(_Health, metaclass=_HealthEnumTypeWrapper): ...
    HEALTH_UNKNOWN: Cluster.Health.ValueType  # 0
    """Health of the cluster is unknown ([Host.health] for every host in the cluster is UNKNOWN)."""
    ALIVE: Cluster.Health.ValueType  # 1
    """Cluster is working normally ([Host.health] for every host in the cluster is ALIVE)."""
    DEAD: Cluster.Health.ValueType  # 2
    """Cluster is inoperable ([Host.health] for every host in the cluster is DEAD)."""
    DEGRADED: Cluster.Health.ValueType  # 3
    """Cluster is working below capacity ([Host.health] for at least one host in the cluster is not ALIVE)."""

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Cluster._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNKNOWN: Cluster._Status.ValueType  # 0
        """Cluster state is unknown."""
        CREATING: Cluster._Status.ValueType  # 1
        """Cluster is being created."""
        RUNNING: Cluster._Status.ValueType  # 2
        """Cluster is running normally."""
        ERROR: Cluster._Status.ValueType  # 3
        """Cluster has encountered a problem and cannot operate."""
        UPDATING: Cluster._Status.ValueType  # 4
        """Cluster is being updated."""
        STOPPING: Cluster._Status.ValueType  # 5
        """Cluster is stopping."""
        STOPPED: Cluster._Status.ValueType  # 6
        """Cluster has stopped."""
        STARTING: Cluster._Status.ValueType  # 7
        """Cluster is starting."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper):
        """Current state of the cluster."""

    STATUS_UNKNOWN: Cluster.Status.ValueType  # 0
    """Cluster state is unknown."""
    CREATING: Cluster.Status.ValueType  # 1
    """Cluster is being created."""
    RUNNING: Cluster.Status.ValueType  # 2
    """Cluster is running normally."""
    ERROR: Cluster.Status.ValueType  # 3
    """Cluster has encountered a problem and cannot operate."""
    UPDATING: Cluster.Status.ValueType  # 4
    """Cluster is being updated."""
    STOPPING: Cluster.Status.ValueType  # 5
    """Cluster is stopping."""
    STOPPED: Cluster.Status.ValueType  # 6
    """Cluster has stopped."""
    STARTING: Cluster.Status.ValueType  # 7
    """Cluster is starting."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    ENVIRONMENT_FIELD_NUMBER: builtins.int
    MONITORING_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    NETWORK_ID_FIELD_NUMBER: builtins.int
    HEALTH_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    PLANNED_OPERATION_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the OpenSearch cluster.
    This ID is assigned by the platform at the moment of cluster creation.
    """
    folder_id: builtins.str
    """ID of the folder that the OpenSearch cluster belongs to."""
    name: builtins.str
    """Name of the OpenSearch cluster.
    The name is unique within the folder. 1-63 characters long.
    """
    description: builtins.str
    """Description of the OpenSearch cluster. 0-256 characters long."""
    environment: global___Cluster.Environment.ValueType
    """Deployment environment of the OpenSearch cluster."""
    network_id: builtins.str
    """ID of the cloud network that the cluster belongs to."""
    health: global___Cluster.Health.ValueType
    """Aggregated cluster health."""
    status: global___Cluster.Status.ValueType
    """Current state of the cluster."""
    service_account_id: builtins.str
    """ID of the service account used to access Object Storage."""
    deletion_protection: builtins.bool
    """Determines whether the cluster is protected from being deleted."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when the cluster was created."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels for the OpenSearch cluster as `key:value` pairs.
        Maximum 64 labels per resource.
        """

    @property
    def monitoring(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Monitoring]:
        """Description of monitoring systems relevant to the OpenSearch cluster."""

    @property
    def config(self) -> global___ClusterConfig:
        """Configuration of the OpenSearch cluster."""

    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """User security groups."""

    @property
    def maintenance_window(self) -> yandex.cloud.mdb.opensearch.v1.maintenance_pb2.MaintenanceWindow:
        """Cluster maintenance window. Should be defined by either one of the two options."""

    @property
    def planned_operation(self) -> yandex.cloud.mdb.opensearch.v1.maintenance_pb2.MaintenanceOperation:
        """Maintenance operation planned at nearest [maintenance_window]."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        environment: global___Cluster.Environment.ValueType = ...,
        monitoring: collections.abc.Iterable[global___Monitoring] | None = ...,
        config: global___ClusterConfig | None = ...,
        network_id: builtins.str = ...,
        health: global___Cluster.Health.ValueType = ...,
        status: global___Cluster.Status.ValueType = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        service_account_id: builtins.str = ...,
        deletion_protection: builtins.bool = ...,
        maintenance_window: yandex.cloud.mdb.opensearch.v1.maintenance_pb2.MaintenanceWindow | None = ...,
        planned_operation: yandex.cloud.mdb.opensearch.v1.maintenance_pb2.MaintenanceOperation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["config", b"config", "created_at", b"created_at", "maintenance_window", b"maintenance_window", "planned_operation", b"planned_operation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["config", b"config", "created_at", b"created_at", "deletion_protection", b"deletion_protection", "description", b"description", "environment", b"environment", "folder_id", b"folder_id", "health", b"health", "id", b"id", "labels", b"labels", "maintenance_window", b"maintenance_window", "monitoring", b"monitoring", "name", b"name", "network_id", b"network_id", "planned_operation", b"planned_operation", "security_group_ids", b"security_group_ids", "service_account_id", b"service_account_id", "status", b"status"]) -> None: ...

global___Cluster = Cluster

@typing.final
class Monitoring(google.protobuf.message.Message):
    """Monitoring system metadata."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the monitoring system."""
    description: builtins.str
    """Description of the monitoring system."""
    link: builtins.str
    """Link to the monitoring system charts for the OpenSearch cluster."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        description: builtins.str = ...,
        link: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "link", b"link", "name", b"name"]) -> None: ...

global___Monitoring = Monitoring

@typing.final
class ClusterConfig(google.protobuf.message.Message):
    """The OpenSearch cluster configuration."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_FIELD_NUMBER: builtins.int
    OPENSEARCH_FIELD_NUMBER: builtins.int
    DASHBOARDS_FIELD_NUMBER: builtins.int
    ACCESS_FIELD_NUMBER: builtins.int
    version: builtins.str
    """Version of the OpenSearch server software."""
    @property
    def opensearch(self) -> global___OpenSearch:
        """OpenSearch configuration."""

    @property
    def dashboards(self) -> global___Dashboards:
        """Dashboards configuration."""

    @property
    def access(self) -> global___Access:
        """Access policy for external services."""

    def __init__(
        self,
        *,
        version: builtins.str = ...,
        opensearch: global___OpenSearch | None = ...,
        dashboards: global___Dashboards | None = ...,
        access: global___Access | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["access", b"access", "dashboards", b"dashboards", "opensearch", b"opensearch"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["access", b"access", "dashboards", b"dashboards", "opensearch", b"opensearch", "version", b"version"]) -> None: ...

global___ClusterConfig = ClusterConfig

@typing.final
class OpenSearch(google.protobuf.message.Message):
    """The OpenSearch host group type configuration."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _GroupRole:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _GroupRoleEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[OpenSearch._GroupRole.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        GROUP_ROLE_UNSPECIFIED: OpenSearch._GroupRole.ValueType  # 0
        DATA: OpenSearch._GroupRole.ValueType  # 1
        MANAGER: OpenSearch._GroupRole.ValueType  # 2

    class GroupRole(_GroupRole, metaclass=_GroupRoleEnumTypeWrapper): ...
    GROUP_ROLE_UNSPECIFIED: OpenSearch.GroupRole.ValueType  # 0
    DATA: OpenSearch.GroupRole.ValueType  # 1
    MANAGER: OpenSearch.GroupRole.ValueType  # 2

    @typing.final
    class NodeGroup(google.protobuf.message.Message):
        """Configuration of the host group."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        NAME_FIELD_NUMBER: builtins.int
        RESOURCES_FIELD_NUMBER: builtins.int
        HOSTS_COUNT_FIELD_NUMBER: builtins.int
        ZONE_IDS_FIELD_NUMBER: builtins.int
        SUBNET_IDS_FIELD_NUMBER: builtins.int
        ASSIGN_PUBLIC_IP_FIELD_NUMBER: builtins.int
        ROLES_FIELD_NUMBER: builtins.int
        name: builtins.str
        """Name of the group. Must be 1-63 characters long."""
        hosts_count: builtins.int
        """Number of hosts in the group."""
        assign_public_ip: builtins.bool
        """Determines whether a public IP is assigned to the hosts in the group."""
        @property
        def resources(self) -> global___Resources:
            """Resources allocated to the hosts."""

        @property
        def zone_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """IDs of the availability zones the hosts belong to."""

        @property
        def subnet_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """IDs of the subnets that the hosts belong to."""

        @property
        def roles(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___OpenSearch.GroupRole.ValueType]:
            """Roles of the host group."""

        def __init__(
            self,
            *,
            name: builtins.str = ...,
            resources: global___Resources | None = ...,
            hosts_count: builtins.int = ...,
            zone_ids: collections.abc.Iterable[builtins.str] | None = ...,
            subnet_ids: collections.abc.Iterable[builtins.str] | None = ...,
            assign_public_ip: builtins.bool = ...,
            roles: collections.abc.Iterable[global___OpenSearch.GroupRole.ValueType] | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["resources", b"resources"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["assign_public_ip", b"assign_public_ip", "hosts_count", b"hosts_count", "name", b"name", "resources", b"resources", "roles", b"roles", "subnet_ids", b"subnet_ids", "zone_ids", b"zone_ids"]) -> None: ...

    PLUGINS_FIELD_NUMBER: builtins.int
    NODE_GROUPS_FIELD_NUMBER: builtins.int
    OPENSEARCH_CONFIG_SET_2_FIELD_NUMBER: builtins.int
    KEYSTORE_SETTINGS_FIELD_NUMBER: builtins.int
    @property
    def plugins(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Names of the cluster plugins."""

    @property
    def node_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OpenSearch.NodeGroup]:
        """Host groups of the OpenSearch type."""

    @property
    def opensearch_config_set_2(self) -> yandex.cloud.mdb.opensearch.v1.config.opensearch_pb2.OpenSearchConfigSet2: ...
    @property
    def keystore_settings(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Keystore entries names."""

    def __init__(
        self,
        *,
        plugins: collections.abc.Iterable[builtins.str] | None = ...,
        node_groups: collections.abc.Iterable[global___OpenSearch.NodeGroup] | None = ...,
        opensearch_config_set_2: yandex.cloud.mdb.opensearch.v1.config.opensearch_pb2.OpenSearchConfigSet2 | None = ...,
        keystore_settings: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["config", b"config", "opensearch_config_set_2", b"opensearch_config_set_2"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["config", b"config", "keystore_settings", b"keystore_settings", "node_groups", b"node_groups", "opensearch_config_set_2", b"opensearch_config_set_2", "plugins", b"plugins"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["config", b"config"]) -> typing.Literal["opensearch_config_set_2"] | None: ...

global___OpenSearch = OpenSearch

@typing.final
class Dashboards(google.protobuf.message.Message):
    """The Dashboards host group type configuration."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class NodeGroup(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        NAME_FIELD_NUMBER: builtins.int
        RESOURCES_FIELD_NUMBER: builtins.int
        HOSTS_COUNT_FIELD_NUMBER: builtins.int
        ZONE_IDS_FIELD_NUMBER: builtins.int
        SUBNET_IDS_FIELD_NUMBER: builtins.int
        ASSIGN_PUBLIC_IP_FIELD_NUMBER: builtins.int
        name: builtins.str
        """Name of the group. 1-63 characters long."""
        hosts_count: builtins.int
        """Number of hosts in the group."""
        assign_public_ip: builtins.bool
        """Determines whether a public IP is assigned to the hosts in the group."""
        @property
        def resources(self) -> global___Resources:
            """Resources allocated to the hosts."""

        @property
        def zone_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """IDs of the availability zones the hosts belong to."""

        @property
        def subnet_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """IDs of the subnets that the hosts belong to."""

        def __init__(
            self,
            *,
            name: builtins.str = ...,
            resources: global___Resources | None = ...,
            hosts_count: builtins.int = ...,
            zone_ids: collections.abc.Iterable[builtins.str] | None = ...,
            subnet_ids: collections.abc.Iterable[builtins.str] | None = ...,
            assign_public_ip: builtins.bool = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["resources", b"resources"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["assign_public_ip", b"assign_public_ip", "hosts_count", b"hosts_count", "name", b"name", "resources", b"resources", "subnet_ids", b"subnet_ids", "zone_ids", b"zone_ids"]) -> None: ...

    NODE_GROUPS_FIELD_NUMBER: builtins.int
    @property
    def node_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Dashboards.NodeGroup]:
        """Host groups of the Dashboards type."""

    def __init__(
        self,
        *,
        node_groups: collections.abc.Iterable[global___Dashboards.NodeGroup] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["node_groups", b"node_groups"]) -> None: ...

global___Dashboards = Dashboards

@typing.final
class Resources(google.protobuf.message.Message):
    """A list of computational resources allocated to a host."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_PRESET_ID_FIELD_NUMBER: builtins.int
    DISK_SIZE_FIELD_NUMBER: builtins.int
    DISK_TYPE_ID_FIELD_NUMBER: builtins.int
    resource_preset_id: builtins.str
    """ID of the preset for computational resources allocated to a host."""
    disk_size: builtins.int
    """Volume of the storage used by the host, in bytes."""
    disk_type_id: builtins.str
    """Type of the storage used by the host: `network-hdd`, `network-ssd` or `local-ssd`."""
    def __init__(
        self,
        *,
        resource_preset_id: builtins.str = ...,
        disk_size: builtins.int = ...,
        disk_type_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disk_size", b"disk_size", "disk_type_id", b"disk_type_id", "resource_preset_id", b"resource_preset_id"]) -> None: ...

global___Resources = Resources

@typing.final
class Host(google.protobuf.message.Message):
    """An OpenSearch cluster host resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Health:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _HealthEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Host._Health.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN: Host._Health.ValueType  # 0
        """Health of the host is unknown. Default value."""
        ALIVE: Host._Health.ValueType  # 1
        """The host is performing all its functions normally."""
        DEAD: Host._Health.ValueType  # 2
        """The host is inoperable and cannot perform any of its essential functions."""
        DEGRADED: Host._Health.ValueType  # 3
        """The host is working below capacity or not fully functional."""

    class Health(_Health, metaclass=_HealthEnumTypeWrapper): ...
    UNKNOWN: Host.Health.ValueType  # 0
    """Health of the host is unknown. Default value."""
    ALIVE: Host.Health.ValueType  # 1
    """The host is performing all its functions normally."""
    DEAD: Host.Health.ValueType  # 2
    """The host is inoperable and cannot perform any of its essential functions."""
    DEGRADED: Host.Health.ValueType  # 3
    """The host is working below capacity or not fully functional."""

    class _Type:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Host._Type.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TYPE_UNSPECIFIED: Host._Type.ValueType  # 0
        """Type of the host is unspecified. Default value."""
        OPENSEARCH: Host._Type.ValueType  # 1
        """An OpenSearch type host."""
        DASHBOARDS: Host._Type.ValueType  # 2
        """A Dashboards type host."""

    class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
    TYPE_UNSPECIFIED: Host.Type.ValueType  # 0
    """Type of the host is unspecified. Default value."""
    OPENSEARCH: Host.Type.ValueType  # 1
    """An OpenSearch type host."""
    DASHBOARDS: Host.Type.ValueType  # 2
    """A Dashboards type host."""

    @typing.final
    class CPUMetric(google.protobuf.message.Message):
        """CPU usage of the host."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TIMESTAMP_FIELD_NUMBER: builtins.int
        USED_FIELD_NUMBER: builtins.int
        timestamp: builtins.int
        """Time of the record."""
        used: builtins.float
        """Percentage of the CPU used."""
        def __init__(
            self,
            *,
            timestamp: builtins.int = ...,
            used: builtins.float = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["timestamp", b"timestamp", "used", b"used"]) -> None: ...

    @typing.final
    class MemoryMetric(google.protobuf.message.Message):
        """RAM usage of the host."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TIMESTAMP_FIELD_NUMBER: builtins.int
        USED_FIELD_NUMBER: builtins.int
        TOTAL_FIELD_NUMBER: builtins.int
        timestamp: builtins.int
        """Time of the record."""
        used: builtins.int
        """The amount of RAM used, in bytes."""
        total: builtins.int
        """Total amount of RAM allocated to the host."""
        def __init__(
            self,
            *,
            timestamp: builtins.int = ...,
            used: builtins.int = ...,
            total: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["timestamp", b"timestamp", "total", b"total", "used", b"used"]) -> None: ...

    @typing.final
    class DiskMetric(google.protobuf.message.Message):
        """Disk usage of the host."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TIMESTAMP_FIELD_NUMBER: builtins.int
        USED_FIELD_NUMBER: builtins.int
        TOTAL_FIELD_NUMBER: builtins.int
        timestamp: builtins.int
        """Time of the record."""
        used: builtins.int
        """The amount of disk space used, in bytes."""
        total: builtins.int
        """Total amount of disk space allocated to the host."""
        def __init__(
            self,
            *,
            timestamp: builtins.int = ...,
            used: builtins.int = ...,
            total: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["timestamp", b"timestamp", "total", b"total", "used", b"used"]) -> None: ...

    @typing.final
    class SystemMetrics(google.protobuf.message.Message):
        """Resources used by the host."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CPU_FIELD_NUMBER: builtins.int
        MEMORY_FIELD_NUMBER: builtins.int
        DISK_FIELD_NUMBER: builtins.int
        @property
        def cpu(self) -> global___Host.CPUMetric:
            """CPU usage of the host."""

        @property
        def memory(self) -> global___Host.MemoryMetric:
            """RAM usage of the host."""

        @property
        def disk(self) -> global___Host.DiskMetric:
            """Disk usage of the host."""

        def __init__(
            self,
            *,
            cpu: global___Host.CPUMetric | None = ...,
            memory: global___Host.MemoryMetric | None = ...,
            disk: global___Host.DiskMetric | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["cpu", b"cpu", "disk", b"disk", "memory", b"memory"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["cpu", b"cpu", "disk", b"disk", "memory", b"memory"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    ZONE_ID_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    HEALTH_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    ASSIGN_PUBLIC_IP_FIELD_NUMBER: builtins.int
    SYSTEM_FIELD_NUMBER: builtins.int
    NODE_GROUP_FIELD_NUMBER: builtins.int
    ROLES_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Required. Name of the OpenSearch host.

    The host name is assigned by the platform at creation time and cannot be changed.

    The name is unique across all MDB hosts that exist on the platform, as it defines the FQDN of the host.
    """
    cluster_id: builtins.str
    """Required. ID of the OpenSearch cluster. The ID is assigned by the platform at creation time."""
    zone_id: builtins.str
    """ID of the availability zone the OpenSearch host belongs to."""
    type: global___Host.Type.ValueType
    """Type of the host. If the field has default value, it is not returned in the response."""
    health: global___Host.Health.ValueType
    """Aggregated health of the host. If the field has default value, it is not returned in the response."""
    subnet_id: builtins.str
    """ID of the subnet that the host belongs to."""
    assign_public_ip: builtins.bool
    """Determines whether a public IP is assigned to the host."""
    node_group: builtins.str
    """Name of the host group that the host belongs to."""
    @property
    def resources(self) -> global___Resources:
        """Resources allocated to the OpenSearch host."""

    @property
    def system(self) -> global___Host.SystemMetrics:
        """Resources used by the host."""

    @property
    def roles(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___OpenSearch.GroupRole.ValueType]:
        """Roles of the host."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        cluster_id: builtins.str = ...,
        zone_id: builtins.str = ...,
        resources: global___Resources | None = ...,
        type: global___Host.Type.ValueType = ...,
        health: global___Host.Health.ValueType = ...,
        subnet_id: builtins.str = ...,
        assign_public_ip: builtins.bool = ...,
        system: global___Host.SystemMetrics | None = ...,
        node_group: builtins.str = ...,
        roles: collections.abc.Iterable[global___OpenSearch.GroupRole.ValueType] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resources", b"resources", "system", b"system"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["assign_public_ip", b"assign_public_ip", "cluster_id", b"cluster_id", "health", b"health", "name", b"name", "node_group", b"node_group", "resources", b"resources", "roles", b"roles", "subnet_id", b"subnet_id", "system", b"system", "type", b"type", "zone_id", b"zone_id"]) -> None: ...

global___Host = Host

@typing.final
class Access(google.protobuf.message.Message):
    """Access policy for external services."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_TRANSFER_FIELD_NUMBER: builtins.int
    SERVERLESS_FIELD_NUMBER: builtins.int
    data_transfer: builtins.bool
    """Determines whether the access to Data Transfer is allowed."""
    serverless: builtins.bool
    """Determines whether the access to Serverless is allowed."""
    def __init__(
        self,
        *,
        data_transfer: builtins.bool = ...,
        serverless: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["data_transfer", b"data_transfer", "serverless", b"serverless"]) -> None: ...

global___Access = Access



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.mdb.opensearch.v1.backup_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetBackupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKUP_ID_FIELD_NUMBER: builtins.int
    backup_id: builtins.str
    """ID of the backup to return."""
    def __init__(
        self,
        *,
        backup_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["backup_id", b"backup_id"]) -> None: ...

global___GetBackupRequest = GetBackupRequest

@typing.final
class ListBackupsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list backups in."""
    page_size: builtins.int
    """The maximum number of results per page that should be returned.

    If the number of available results is larger than [page_size], the service returns
    a [ListBackupsResponse.next_page_token] that can be used to get the next page of results
    in subsequent list requests.

    Default value is 100.
    """
    page_token: builtins.str
    """The page token. To get the next page of results, set [page_token] to the [ListBackupsResponse.next_page_token]
    returned by the previous list request.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListBackupsRequest = ListBackupsRequest

@typing.final
class ListBackupsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKUPS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for a list request.

    If the number of results is larger than [ListBackupsRequest.page_size] specified in the request,
    use the [next_page_token] as the value for the [ListBackupsRequest.page_token] parameter in the next list request.

    Each subsequent ListBackups request has its own [next_page_token] to continue paging through the results.
    """
    @property
    def backups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.mdb.opensearch.v1.backup_pb2.Backup]:
        """Requested list of backups."""

    def __init__(
        self,
        *,
        backups: collections.abc.Iterable[yandex.cloud.mdb.opensearch.v1.backup_pb2.Backup] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["backups", b"backups", "next_page_token", b"next_page_token"]) -> None: ...

global___ListBackupsResponse = ListBackupsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.compute.v1.disk_pb2
import yandex.cloud.compute.v1.snapshot_pb2
import yandex.cloud.compute.v1.snapshot_schedule_pb2
import yandex.cloud.operation.operation_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetSnapshotScheduleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SNAPSHOT_SCHEDULE_ID_FIELD_NUMBER: builtins.int
    snapshot_schedule_id: builtins.str
    """ID of the snapshot schedule to return.

    To get a schedule ID, make a [SnapshotScheduleService.List] request.
    """
    def __init__(
        self,
        *,
        snapshot_schedule_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["snapshot_schedule_id", b"snapshot_schedule_id"]) -> None: ...

global___GetSnapshotScheduleRequest = GetSnapshotScheduleRequest

@typing.final
class ListSnapshotSchedulesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list snapshot schedules in.

    To get the folder ID, make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than `page_size`, the service returns a [ListSnapshotSchedulesResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListSnapshotSchedulesResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters snapshot schedules listed in the response.

    The expression must specify:
    1. The field name. Currently you can use filtering only on [SnapshotSchedule.name] field.
    2. An operator. Can be either `=` or `!=` for single values, `IN` or `NOT IN` for lists of values.
    3. The value. Must be 3-63 characters long and match the regular expression `^[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    Example of a filter: `name=my-schedule`.
    """
    order_by: builtins.str
    """A sorting expression that sorts snapshot schedules listed in the response.

    The expression must specify the field name from [SnapshotSchedule] and `asc`ending or `desc`ending order,
    e.g. `createdAt desc`.

    Default value: `id asc`.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
        order_by: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListSnapshotSchedulesRequest = ListSnapshotSchedulesRequest

@typing.final
class ListSnapshotSchedulesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SNAPSHOT_SCHEDULES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListSnapshotSchedulesRequest.page_size], use `next_page_token` as the value
    for the [ListSnapshotSchedulesRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def snapshot_schedules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.compute.v1.snapshot_schedule_pb2.SnapshotSchedule]:
        """List of snapshot schedules in the specified folder."""

    def __init__(
        self,
        *,
        snapshot_schedules: collections.abc.Iterable[yandex.cloud.compute.v1.snapshot_schedule_pb2.SnapshotSchedule] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "snapshot_schedules", b"snapshot_schedules"]) -> None: ...

global___ListSnapshotSchedulesResponse = ListSnapshotSchedulesResponse

@typing.final
class CreateSnapshotScheduleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    SCHEDULE_POLICY_FIELD_NUMBER: builtins.int
    RETENTION_PERIOD_FIELD_NUMBER: builtins.int
    SNAPSHOT_COUNT_FIELD_NUMBER: builtins.int
    SNAPSHOT_SPEC_FIELD_NUMBER: builtins.int
    DISK_IDS_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create a snapshot schedule in.

    Snapshots are created in the same folder as the schedule, even if disks from other folders are attached
    to the schedule.

    To get a folder ID, make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    name: builtins.str
    """Name of the snapshot schedule.

    The name must be unique within the folder.
    """
    description: builtins.str
    """Description of the snapshot schedule."""
    snapshot_count: builtins.int
    """Retention count of the snapshot schedule. Once the number of snapshots created by the schedule exceeds this
    number, the oldest ones are automatically deleted. E.g. if the number is 5, the first snapshot is deleted
    after the sixth one is created, the second is deleted after the seventh one is created, and so on.
    """
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Snapshot schedule labels as `key:value` pairs."""

    @property
    def schedule_policy(self) -> yandex.cloud.compute.v1.snapshot_schedule_pb2.SchedulePolicy:
        """Frequency settings of the snapshot schedule."""

    @property
    def retention_period(self) -> google.protobuf.duration_pb2.Duration:
        """Retention period of the snapshot schedule. Once a snapshot created by the schedule reaches this age, it is
        automatically deleted.
        """

    @property
    def snapshot_spec(self) -> yandex.cloud.compute.v1.snapshot_schedule_pb2.SnapshotSpec:
        """Attributes of snapshots created by the snapshot schedule."""

    @property
    def disk_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of IDs of the disks attached to the snapshot schedule.

        To get a disk ID, make a [yandex.cloud.compute.v1.DiskService.List] request.
        """

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        schedule_policy: yandex.cloud.compute.v1.snapshot_schedule_pb2.SchedulePolicy | None = ...,
        retention_period: google.protobuf.duration_pb2.Duration | None = ...,
        snapshot_count: builtins.int = ...,
        snapshot_spec: yandex.cloud.compute.v1.snapshot_schedule_pb2.SnapshotSpec | None = ...,
        disk_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["retention_period", b"retention_period", "retention_policy", b"retention_policy", "schedule_policy", b"schedule_policy", "snapshot_count", b"snapshot_count", "snapshot_spec", b"snapshot_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "disk_ids", b"disk_ids", "folder_id", b"folder_id", "labels", b"labels", "name", b"name", "retention_period", b"retention_period", "retention_policy", b"retention_policy", "schedule_policy", b"schedule_policy", "snapshot_count", b"snapshot_count", "snapshot_spec", b"snapshot_spec"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["retention_policy", b"retention_policy"]) -> typing.Literal["retention_period", "snapshot_count"] | None: ...

global___CreateSnapshotScheduleRequest = CreateSnapshotScheduleRequest

@typing.final
class CreateSnapshotScheduleMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SNAPSHOT_SCHEDULE_ID_FIELD_NUMBER: builtins.int
    snapshot_schedule_id: builtins.str
    """ID of the snapshot schedule that is being created."""
    def __init__(
        self,
        *,
        snapshot_schedule_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["snapshot_schedule_id", b"snapshot_schedule_id"]) -> None: ...

global___CreateSnapshotScheduleMetadata = CreateSnapshotScheduleMetadata

@typing.final
class UpdateSnapshotScheduleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    SNAPSHOT_SCHEDULE_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    SCHEDULE_POLICY_FIELD_NUMBER: builtins.int
    RETENTION_PERIOD_FIELD_NUMBER: builtins.int
    SNAPSHOT_COUNT_FIELD_NUMBER: builtins.int
    SNAPSHOT_SPEC_FIELD_NUMBER: builtins.int
    snapshot_schedule_id: builtins.str
    """ID of the snapshot schedule to update.

    To get the snapshot schedule ID, make a [SnapshotScheduleService.List] request.
    """
    name: builtins.str
    """New name for the snapshot schedule.

    The name must be unique within the folder.
    """
    description: builtins.str
    """New description of the snapshot schedule."""
    snapshot_count: builtins.int
    """Retention count of the snapshot schedule. Once the number of snapshots created by the schedule exceeds this
    number, the oldest ones are automatically deleted. E.g. if the number is 5, the first snapshot is deleted
    after the sixth one is created, the second is deleted after the seventh one is created, and so on.
    """
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which attributes of the snapshot schedule should be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Snapshot schedule labels as `key:value` pairs.

        Existing set of labels is completely replaced by the provided set, so if you just want
        to add or remove a label:
        1. Get the current set of labels with a [SnapshotScheduleService.Get] request.
        2. Add or remove a label in this set.
        3. Send the new set in this field.
        """

    @property
    def schedule_policy(self) -> yandex.cloud.compute.v1.snapshot_schedule_pb2.SchedulePolicy:
        """New frequency settings of the snapshot schedule."""

    @property
    def retention_period(self) -> google.protobuf.duration_pb2.Duration:
        """Retention period of the snapshot schedule. Once a snapshot created by the schedule reaches this age, it is
        automatically deleted.
        """

    @property
    def snapshot_spec(self) -> yandex.cloud.compute.v1.snapshot_schedule_pb2.SnapshotSpec:
        """New attributes of snapshots created by the snapshot schedule."""

    def __init__(
        self,
        *,
        snapshot_schedule_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        schedule_policy: yandex.cloud.compute.v1.snapshot_schedule_pb2.SchedulePolicy | None = ...,
        retention_period: google.protobuf.duration_pb2.Duration | None = ...,
        snapshot_count: builtins.int = ...,
        snapshot_spec: yandex.cloud.compute.v1.snapshot_schedule_pb2.SnapshotSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["retention_period", b"retention_period", "retention_policy", b"retention_policy", "schedule_policy", b"schedule_policy", "snapshot_count", b"snapshot_count", "snapshot_spec", b"snapshot_spec", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "labels", b"labels", "name", b"name", "retention_period", b"retention_period", "retention_policy", b"retention_policy", "schedule_policy", b"schedule_policy", "snapshot_count", b"snapshot_count", "snapshot_schedule_id", b"snapshot_schedule_id", "snapshot_spec", b"snapshot_spec", "update_mask", b"update_mask"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["retention_policy", b"retention_policy"]) -> typing.Literal["retention_period", "snapshot_count"] | None: ...

global___UpdateSnapshotScheduleRequest = UpdateSnapshotScheduleRequest

@typing.final
class UpdateSnapshotScheduleMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SNAPSHOT_SCHEDULE_ID_FIELD_NUMBER: builtins.int
    snapshot_schedule_id: builtins.str
    """ID of the snapshot schedule that is being updated."""
    def __init__(
        self,
        *,
        snapshot_schedule_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["snapshot_schedule_id", b"snapshot_schedule_id"]) -> None: ...

global___UpdateSnapshotScheduleMetadata = UpdateSnapshotScheduleMetadata

@typing.final
class DeleteSnapshotScheduleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SNAPSHOT_SCHEDULE_ID_FIELD_NUMBER: builtins.int
    snapshot_schedule_id: builtins.str
    """ID of the snapshot schedule to delete.

    To get a snapshot schedule ID, make a [SnapshotScheduleService.List] request.
    """
    def __init__(
        self,
        *,
        snapshot_schedule_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["snapshot_schedule_id", b"snapshot_schedule_id"]) -> None: ...

global___DeleteSnapshotScheduleRequest = DeleteSnapshotScheduleRequest

@typing.final
class DeleteSnapshotScheduleMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SNAPSHOT_SCHEDULE_ID_FIELD_NUMBER: builtins.int
    snapshot_schedule_id: builtins.str
    """ID of the snapshot schedule that is being deleted."""
    def __init__(
        self,
        *,
        snapshot_schedule_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["snapshot_schedule_id", b"snapshot_schedule_id"]) -> None: ...

global___DeleteSnapshotScheduleMetadata = DeleteSnapshotScheduleMetadata

@typing.final
class DisableSnapshotScheduleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SNAPSHOT_SCHEDULE_ID_FIELD_NUMBER: builtins.int
    snapshot_schedule_id: builtins.str
    """ID of the snapshot schedule to disable.

    To get a snapshot schedule ID, make a [SnapshotScheduleService.List] request.
    """
    def __init__(
        self,
        *,
        snapshot_schedule_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["snapshot_schedule_id", b"snapshot_schedule_id"]) -> None: ...

global___DisableSnapshotScheduleRequest = DisableSnapshotScheduleRequest

@typing.final
class DisableSnapshotScheduleMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SNAPSHOT_SCHEDULE_ID_FIELD_NUMBER: builtins.int
    snapshot_schedule_id: builtins.str
    """ID of the snapshot schedule that is being disabled."""
    def __init__(
        self,
        *,
        snapshot_schedule_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["snapshot_schedule_id", b"snapshot_schedule_id"]) -> None: ...

global___DisableSnapshotScheduleMetadata = DisableSnapshotScheduleMetadata

@typing.final
class EnableSnapshotScheduleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SNAPSHOT_SCHEDULE_ID_FIELD_NUMBER: builtins.int
    snapshot_schedule_id: builtins.str
    """ID of the snapshot schedule to enable.

    To get a snapshot schedule ID, make a [SnapshotScheduleService.List] request.
    """
    def __init__(
        self,
        *,
        snapshot_schedule_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["snapshot_schedule_id", b"snapshot_schedule_id"]) -> None: ...

global___EnableSnapshotScheduleRequest = EnableSnapshotScheduleRequest

@typing.final
class EnableSnapshotScheduleMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SNAPSHOT_SCHEDULE_ID_FIELD_NUMBER: builtins.int
    snapshot_schedule_id: builtins.str
    """ID of the snapshot schedule that is being enabled."""
    def __init__(
        self,
        *,
        snapshot_schedule_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["snapshot_schedule_id", b"snapshot_schedule_id"]) -> None: ...

global___EnableSnapshotScheduleMetadata = EnableSnapshotScheduleMetadata

@typing.final
class ListSnapshotScheduleOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SNAPSHOT_SCHEDULE_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    snapshot_schedule_id: builtins.str
    """ID of the snapshot schedule to list operations for.

    To get a snapshot schedule ID, make a [SnapshotScheduleService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListSnapshotScheduleOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.

    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListSnapshotScheduleOperationsResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        snapshot_schedule_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["page_size", b"page_size", "page_token", b"page_token", "snapshot_schedule_id", b"snapshot_schedule_id"]) -> None: ...

global___ListSnapshotScheduleOperationsRequest = ListSnapshotScheduleOperationsRequest

@typing.final
class ListSnapshotScheduleOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListSnapshotScheduleOperationsRequest.page_size], use `next_page_token` as the value
    for the [ListSnapshotScheduleOperationsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified snapshot schedule."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListSnapshotScheduleOperationsResponse = ListSnapshotScheduleOperationsResponse

@typing.final
class ListSnapshotScheduleSnapshotsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SNAPSHOT_SCHEDULE_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    snapshot_schedule_id: builtins.str
    """ID of the snapshot schedule to list created snapshots for.

    To get a snapshot schedule ID, make a [SnapshotScheduleService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListSnapshotScheduleOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.

    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListSnapshotScheduleOperationsResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        snapshot_schedule_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["page_size", b"page_size", "page_token", b"page_token", "snapshot_schedule_id", b"snapshot_schedule_id"]) -> None: ...

global___ListSnapshotScheduleSnapshotsRequest = ListSnapshotScheduleSnapshotsRequest

@typing.final
class ListSnapshotScheduleSnapshotsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SNAPSHOTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListSnapshotScheduleSnapshotsRequest.page_size], use `next_page_token` as the value
    for the [ListSnapshotScheduleSnapshotsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def snapshots(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.compute.v1.snapshot_pb2.Snapshot]:
        """List of snapshots created by the specified snapshot schedule."""

    def __init__(
        self,
        *,
        snapshots: collections.abc.Iterable[yandex.cloud.compute.v1.snapshot_pb2.Snapshot] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "snapshots", b"snapshots"]) -> None: ...

global___ListSnapshotScheduleSnapshotsResponse = ListSnapshotScheduleSnapshotsResponse

@typing.final
class ListSnapshotScheduleDisksRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SNAPSHOT_SCHEDULE_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    snapshot_schedule_id: builtins.str
    """ID of the snapshot schedule to list attached disks for.

    To get a snapshot schedule ID, make a [SnapshotScheduleService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListSnapshotScheduleDisksResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.

    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListSnapshotScheduleDisksResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        snapshot_schedule_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["page_size", b"page_size", "page_token", b"page_token", "snapshot_schedule_id", b"snapshot_schedule_id"]) -> None: ...

global___ListSnapshotScheduleDisksRequest = ListSnapshotScheduleDisksRequest

@typing.final
class ListSnapshotScheduleDisksResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISKS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListSnapshotScheduleDisksRequest.page_size], use `next_page_token` as the value
    for the [ListSnapshotScheduleDisksRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def disks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.compute.v1.disk_pb2.Disk]:
        """List of disks attached to the specified snapshot schedule."""

    def __init__(
        self,
        *,
        disks: collections.abc.Iterable[yandex.cloud.compute.v1.disk_pb2.Disk] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disks", b"disks", "next_page_token", b"next_page_token"]) -> None: ...

global___ListSnapshotScheduleDisksResponse = ListSnapshotScheduleDisksResponse

@typing.final
class UpdateSnapshotScheduleDisksRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SNAPSHOT_SCHEDULE_ID_FIELD_NUMBER: builtins.int
    REMOVE_FIELD_NUMBER: builtins.int
    ADD_FIELD_NUMBER: builtins.int
    snapshot_schedule_id: builtins.str
    """ID of the snapshot schedule to update.

    To get a snapshot schedule ID, make a [SnapshotScheduleService.List] request.
    """
    @property
    def remove(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of IDs of the disks to detach from the specified schedule.

        To get an ID of a disk attached to the schedule, make a [SnapshotScheduleService.ListDisks] request.
        """

    @property
    def add(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of IDs of the disks to attach to the specified schedule.

        To get a disk ID, make a [yandex.cloud.compute.v1.DiskService.List] request.
        """

    def __init__(
        self,
        *,
        snapshot_schedule_id: builtins.str = ...,
        remove: collections.abc.Iterable[builtins.str] | None = ...,
        add: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["add", b"add", "remove", b"remove", "snapshot_schedule_id", b"snapshot_schedule_id"]) -> None: ...

global___UpdateSnapshotScheduleDisksRequest = UpdateSnapshotScheduleDisksRequest

@typing.final
class UpdateSnapshotScheduleDisksMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SNAPSHOT_SCHEDULE_ID_FIELD_NUMBER: builtins.int
    snapshot_schedule_id: builtins.str
    """ID of the snapshot schedule that is being updated."""
    def __init__(
        self,
        *,
        snapshot_schedule_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["snapshot_schedule_id", b"snapshot_schedule_id"]) -> None: ...

global___UpdateSnapshotScheduleDisksMetadata = UpdateSnapshotScheduleDisksMetadata



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/tts/v3/tts_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.ai.tts.v3 import tts_pb2 as yandex_dot_cloud_dot_ai_dot_tts_dot_v3_dot_tts__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(yandex/cloud/ai/tts/v3/tts_service.proto\x12\x10speechkit.tts.v3\x1a yandex/cloud/ai/tts/v3/tts.proto\x1a\x1cgoogle/api/annotations.proto2\xa8\x01\n\x0bSynthesizer\x12\x98\x01\n\x12UtteranceSynthesis\x12+.speechkit.tts.v3.UtteranceSynthesisRequest\x1a,.speechkit.tts.v3.UtteranceSynthesisResponse\"%\x82\xd3\xe4\x93\x02\x1f\"\x1a/tts/v3/utteranceSynthesis:\x01*0\x01\x42\\\n\x1ayandex.cloud.api.ai.tts.v3Z>github.com/yandex-cloud/go-genproto/yandex/cloud/ai/tts/v3;ttsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.tts.v3.tts_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032yandex.cloud.api.ai.tts.v3Z>github.com/yandex-cloud/go-genproto/yandex/cloud/ai/tts/v3;tts'
  _SYNTHESIZER.methods_by_name['UtteranceSynthesis']._options = None
  _SYNTHESIZER.methods_by_name['UtteranceSynthesis']._serialized_options = b'\202\323\344\223\002\037\"\032/tts/v3/utteranceSynthesis:\001*'
  _globals['_SYNTHESIZER']._serialized_start=127
  _globals['_SYNTHESIZER']._serialized_end=295
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.access.access_pb2
import yandex.cloud.compute.v1.instancegroup.instance_group_pb2
import yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class InstanceGroupServiceStub:
    """A set of methods for managing InstanceGroup resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.GetInstanceGroupRequest,
        yandex.cloud.compute.v1.instancegroup.instance_group_pb2.InstanceGroup,
    ]
    """Returns the specified InstanceGroup resource.

    To get the list of available InstanceGroup resources, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.ListInstanceGroupsRequest,
        yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.ListInstanceGroupsResponse,
    ]
    """Retrieves the list of InstanceGroup resources in the specified folder."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.CreateInstanceGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates an instance group in the specified folder.
    This method starts an operation that can be cancelled by another operation.
    """

    CreateFromYaml: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.CreateInstanceGroupFromYamlRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates an instance group in the specified folder from a YAML file.
    This method starts an operation that can be cancelled by another operation.
    """

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.UpdateInstanceGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified instance group.
    This method starts an operation that can be cancelled by another operation.
    """

    UpdateFromYaml: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.UpdateInstanceGroupFromYamlRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified instance group from a YAML file.
    This method starts an operation that can be cancelled by another operation.
    """

    Stop: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.StopInstanceGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Stops the specified instance group."""

    RollingRestart: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.RollingRestartRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Performs rolling restart of specified instances for the specified instance group.
    Rolling restart does restart of instances respecting all group policies.
    """

    RollingRecreate: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.RollingRecreateRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Performs rolling recreate of specified instances for the specified instance group.
    Rolling recreate does recreate of instance VMs respecting all group policies.
    """

    Start: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.StartInstanceGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Starts the specified instance group."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.DeleteInstanceGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified instance group."""

    ListInstances: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.ListInstanceGroupInstancesRequest,
        yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.ListInstanceGroupInstancesResponse,
    ]
    """Lists instances for the specified instance group."""

    DeleteInstances: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.DeleteInstancesRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Delete instances from the instance group."""

    StopInstances: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.StopInstancesRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Stop instances from the instance group."""

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.ListInstanceGroupOperationsRequest,
        yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.ListInstanceGroupOperationsResponse,
    ]
    """Lists operations for the specified instance group."""

    ListLogRecords: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.ListInstanceGroupLogRecordsRequest,
        yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.ListInstanceGroupLogRecordsResponse,
    ]
    """Lists logs for the specified instance group."""

    ListAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """Lists existing access bindings for the specified instance group."""

    SetAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the specified instance group."""

    UpdateAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the specified instance group."""

    ResumeProcesses: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.ResumeInstanceGroupProcessesRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Resumes all processes regarding management of the specified instance group,
    i.e. scaling, checking instances' health, auto-healing and updating them.
    """

    PauseProcesses: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.PauseInstanceGroupProcessesRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Pauses all processes regarding management of the specified instance group,
    i.e. scaling, checking instances' health, auto-healing and updating them. Running instances are not stopped.
    """

class InstanceGroupServiceAsyncStub:
    """A set of methods for managing InstanceGroup resources."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.GetInstanceGroupRequest,
        yandex.cloud.compute.v1.instancegroup.instance_group_pb2.InstanceGroup,
    ]
    """Returns the specified InstanceGroup resource.

    To get the list of available InstanceGroup resources, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.ListInstanceGroupsRequest,
        yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.ListInstanceGroupsResponse,
    ]
    """Retrieves the list of InstanceGroup resources in the specified folder."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.CreateInstanceGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates an instance group in the specified folder.
    This method starts an operation that can be cancelled by another operation.
    """

    CreateFromYaml: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.CreateInstanceGroupFromYamlRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates an instance group in the specified folder from a YAML file.
    This method starts an operation that can be cancelled by another operation.
    """

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.UpdateInstanceGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified instance group.
    This method starts an operation that can be cancelled by another operation.
    """

    UpdateFromYaml: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.UpdateInstanceGroupFromYamlRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified instance group from a YAML file.
    This method starts an operation that can be cancelled by another operation.
    """

    Stop: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.StopInstanceGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Stops the specified instance group."""

    RollingRestart: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.RollingRestartRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Performs rolling restart of specified instances for the specified instance group.
    Rolling restart does restart of instances respecting all group policies.
    """

    RollingRecreate: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.RollingRecreateRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Performs rolling recreate of specified instances for the specified instance group.
    Rolling recreate does recreate of instance VMs respecting all group policies.
    """

    Start: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.StartInstanceGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Starts the specified instance group."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.DeleteInstanceGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified instance group."""

    ListInstances: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.ListInstanceGroupInstancesRequest,
        yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.ListInstanceGroupInstancesResponse,
    ]
    """Lists instances for the specified instance group."""

    DeleteInstances: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.DeleteInstancesRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Delete instances from the instance group."""

    StopInstances: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.StopInstancesRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Stop instances from the instance group."""

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.ListInstanceGroupOperationsRequest,
        yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.ListInstanceGroupOperationsResponse,
    ]
    """Lists operations for the specified instance group."""

    ListLogRecords: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.ListInstanceGroupLogRecordsRequest,
        yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.ListInstanceGroupLogRecordsResponse,
    ]
    """Lists logs for the specified instance group."""

    ListAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """Lists existing access bindings for the specified instance group."""

    SetAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the specified instance group."""

    UpdateAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the specified instance group."""

    ResumeProcesses: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.ResumeInstanceGroupProcessesRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Resumes all processes regarding management of the specified instance group,
    i.e. scaling, checking instances' health, auto-healing and updating them.
    """

    PauseProcesses: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.PauseInstanceGroupProcessesRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Pauses all processes regarding management of the specified instance group,
    i.e. scaling, checking instances' health, auto-healing and updating them. Running instances are not stopped.
    """

class InstanceGroupServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing InstanceGroup resources."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.GetInstanceGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.compute.v1.instancegroup.instance_group_pb2.InstanceGroup, collections.abc.Awaitable[yandex.cloud.compute.v1.instancegroup.instance_group_pb2.InstanceGroup]]:
        """Returns the specified InstanceGroup resource.

        To get the list of available InstanceGroup resources, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.ListInstanceGroupsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.ListInstanceGroupsResponse, collections.abc.Awaitable[yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.ListInstanceGroupsResponse]]:
        """Retrieves the list of InstanceGroup resources in the specified folder."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.CreateInstanceGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates an instance group in the specified folder.
        This method starts an operation that can be cancelled by another operation.
        """

    @abc.abstractmethod
    def CreateFromYaml(
        self,
        request: yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.CreateInstanceGroupFromYamlRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates an instance group in the specified folder from a YAML file.
        This method starts an operation that can be cancelled by another operation.
        """

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.UpdateInstanceGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified instance group.
        This method starts an operation that can be cancelled by another operation.
        """

    @abc.abstractmethod
    def UpdateFromYaml(
        self,
        request: yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.UpdateInstanceGroupFromYamlRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified instance group from a YAML file.
        This method starts an operation that can be cancelled by another operation.
        """

    @abc.abstractmethod
    def Stop(
        self,
        request: yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.StopInstanceGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Stops the specified instance group."""

    @abc.abstractmethod
    def RollingRestart(
        self,
        request: yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.RollingRestartRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Performs rolling restart of specified instances for the specified instance group.
        Rolling restart does restart of instances respecting all group policies.
        """

    @abc.abstractmethod
    def RollingRecreate(
        self,
        request: yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.RollingRecreateRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Performs rolling recreate of specified instances for the specified instance group.
        Rolling recreate does recreate of instance VMs respecting all group policies.
        """

    @abc.abstractmethod
    def Start(
        self,
        request: yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.StartInstanceGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Starts the specified instance group."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.DeleteInstanceGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified instance group."""

    @abc.abstractmethod
    def ListInstances(
        self,
        request: yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.ListInstanceGroupInstancesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.ListInstanceGroupInstancesResponse, collections.abc.Awaitable[yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.ListInstanceGroupInstancesResponse]]:
        """Lists instances for the specified instance group."""

    @abc.abstractmethod
    def DeleteInstances(
        self,
        request: yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.DeleteInstancesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Delete instances from the instance group."""

    @abc.abstractmethod
    def StopInstances(
        self,
        request: yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.StopInstancesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Stop instances from the instance group."""

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.ListInstanceGroupOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.ListInstanceGroupOperationsResponse, collections.abc.Awaitable[yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.ListInstanceGroupOperationsResponse]]:
        """Lists operations for the specified instance group."""

    @abc.abstractmethod
    def ListLogRecords(
        self,
        request: yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.ListInstanceGroupLogRecordsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.ListInstanceGroupLogRecordsResponse, collections.abc.Awaitable[yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.ListInstanceGroupLogRecordsResponse]]:
        """Lists logs for the specified instance group."""

    @abc.abstractmethod
    def ListAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.access.access_pb2.ListAccessBindingsResponse, collections.abc.Awaitable[yandex.cloud.access.access_pb2.ListAccessBindingsResponse]]:
        """Lists existing access bindings for the specified instance group."""

    @abc.abstractmethod
    def SetAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Sets access bindings for the specified instance group."""

    @abc.abstractmethod
    def UpdateAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates access bindings for the specified instance group."""

    @abc.abstractmethod
    def ResumeProcesses(
        self,
        request: yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.ResumeInstanceGroupProcessesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Resumes all processes regarding management of the specified instance group,
        i.e. scaling, checking instances' health, auto-healing and updating them.
        """

    @abc.abstractmethod
    def PauseProcesses(
        self,
        request: yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2.PauseInstanceGroupProcessesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Pauses all processes regarding management of the specified instance group,
        i.e. scaling, checking instances' health, auto-healing and updating them. Running instances are not stopped.
        """

def add_InstanceGroupServiceServicer_to_server(servicer: InstanceGroupServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
